@@ -11,11 +11,6 @@
 
 #include "core/types.h"
 
-namespace KGAPI2
-{
-class Job;
-}
-
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
