@@ -51,14 +51,14 @@ public:
     TeamdriveFetchJob(const QString &teamdriveId, const AccountPtr &account, QObject *parent = nullptr);
     ~TeamdriveFetchJob() override;
 
-    int maxResults() const;
+    [[nodiscard]] int maxResults() const;
     void setMaxResults(int maxResults);
 
     void setUseDomainAdminAccess(bool useDomainAdminAccess);
-    bool useDomainAdminAccess() const;
+    [[nodiscard]] bool useDomainAdminAccess() const;
 
     void setFields(const QStringList &fields);
-    QStringList fields() const;
+    [[nodiscard]] QStringList fields() const;
 
 protected:
     void start() override;
